Placement enum

Indicates the placement of a node with respect to another node.

Used in the TreeView.indicatorBuilder to indicate the placement of the indicator with respect to the given node.

Inheritance
Available extensions

Values

above → const Placement

Placed above.

below → const Placement

Placed below.

child → const Placement

Placed as child.

none → const Placement

Not placed in the tree.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Placement>
A constant List of the values in this enum, in order of their declaration.