getByIdentifier method
Get a node registered in this controller by its identifier.
will throw if no corresponding node is found, if you are unsure wether the node will be available use maybeGetByIdentifier instead
Implementation
TreeNode getByIdentifier(Object identifier, {bool notify = true}) {
final node = _nodeMap[identifier];
assert(node != null, 'No node registered with this identifier');
return node!;
}