allowPlacement property

bool Function(TreeNode<Object?> referenceNode, Placement intendedPlacement)? allowPlacement
final

Wether or not the user is allowed to place the node at the intended placement with reference to the passed node.

Implementation

final bool Function(TreeNode referenceNode, Placement intendedPlacement)?
allowPlacement;