interactive_tree_view
library
Classes
-
DefaultIndicator
-
The default indicator for a treeview.
-
StaticTreeview
-
A widget used to render a treeview in the ui, this tree does not take a controller but root nodes instead.
Use this widget if you want to display a treeview that the user can not modify.
-
TreeController
-
A controller that manages a tree consisting of many treenodes.
Exposes methods to: get, attach, move, delete or modify nodes.
-
TreeNode<T extends Object?>
-
An element of a tree. A tree (managed by a controller) contains many nodes.
The nodes define the structure of the tree.
-
TreeView
-
A widget used to render a treeview in the ui, based on the state of this tree inside the controller.
Enums
-
DragStartMode
-
Defines how drag interactions begin inside the tree view.
-
Placement
-
Indicates the placement of a node with respect to another node.